==> haskell-equivalence-0.3.4-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: equivalence
version: 0.3.4
id: equivalence-0.3.4-9be9Ckn0zVZI5K0ElkOkE3
key: equivalence-0.3.4-9be9Ckn0zVZI5K0ElkOkE3
license: BSD-3-Clause
maintainer: paba@itu.dk
author: Patrick Bahr
stability: provisional
homepage: https://github.com/pa-ba/equivalence
synopsis: Maintaining an equivalence relation implemented as union-find using STT.
description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).
category: Algorithms, Data
abi: afede0fe2e286a771d88c491cadb20cf
exposed: True
exposed-modules:
    Data.Equivalence.Monad Data.Equivalence.STT
import-dirs: /usr/lib/ghc-8.6.5/site-local/equivalence-0.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/equivalence-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/equivalence-0.3.4
hs-libraries: HSequivalence-0.3.4-9be9Ckn0zVZI5K0ElkOkE3
depends:
    STMonadTrans-0.4.3-FHaBKWFZfyp9xAiSNf90KJ base-4.12.0.0
    containers-0.6.0.1 mtl-2.2.2 transformers-0.5.6.2
    transformers-compat-0.6.4-3mIoeQKAFq789cuQC8bUpt
haddock-interfaces: /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html: /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-equivalence-0.3.4-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: equivalence
version: 0.3.4
id: equivalence-0.3.4-9d3PDQQ95zcBwd5pUNIUBn
key: equivalence-0.3.4-9d3PDQQ95zcBwd5pUNIUBn
license: BSD-3-Clause
maintainer: paba@itu.dk
author: Patrick Bahr
stability: provisional
homepage: https://github.com/pa-ba/equivalence
synopsis: Maintaining an equivalence relation implemented as union-find using STT.
description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).
category: Algorithms, Data
abi: 0e0a968d52285c4dabdd5a82cc2082d6
exposed: True
exposed-modules:
    Data.Equivalence.Monad Data.Equivalence.STT
import-dirs: /usr/lib/ghc-8.6.5/site-local/equivalence-0.3.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/equivalence-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/equivalence-0.3.4
hs-libraries: HSequivalence-0.3.4-9d3PDQQ95zcBwd5pUNIUBn
depends:
    STMonadTrans-0.4.3-FHaBKWFZfyp9xAiSNf90KJ base-4.12.0.0
    containers-0.6.0.1 mtl-2.2.2 transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html: /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
